@@ -42,6 +42,8 @@
 #include <gdk/wayland/presentation-time-client-protocol.h>
 #include <gdk/wayland/single-pixel-buffer-v1-client-protocol.h>
 #include <gdk/wayland/xdg-dialog-v1-client-protocol.h>
+#include <gdk/wayland/xdg-system-bell-v1-client-protocol.h>
+#include <gdk/wayland/cursor-shape-v1-client-protocol.h>
 
 #include <glib.h>
 #include <gdk/gdkkeys.h>
@@ -106,6 +108,7 @@ struct _GdkWaylandDisplay
   struct zxdg_shell_v6 *zxdg_shell_v6;
   struct xdg_wm_dialog_v1 *xdg_wm_dialog;
   struct gtk_shell1 *gtk_shell;
+  struct xdg_system_bell_v1 *system_bell;
   struct wl_data_device_manager *data_device_manager;
   struct wl_subcompositor *subcompositor;
   struct zwp_pointer_gestures_v1 *pointer_gestures;
@@ -124,6 +127,7 @@ struct _GdkWaylandDisplay
   struct wp_viewporter *viewporter;
   struct wp_presentation *presentation;
   struct wp_single_pixel_buffer_manager_v1 *single_pixel_buffer;
+  struct wp_cursor_shape_manager_v1 *cursor_shape;
   GdkWaylandColor *color;
 
   GList *async_roundtrips;
