@@ -54,6 +54,7 @@ gdk_wayland_subsurface_finalize (GObject *object)
   g_clear_pointer (&self->bg_viewport, wp_viewport_destroy);
   g_clear_pointer (&self->bg_subsurface, wl_subsurface_destroy);
   g_clear_pointer (&self->bg_surface, wl_surface_destroy);
+  g_clear_pointer (&self->idle_inhibitor, zwp_idle_inhibitor_v1_destroy);
 
   G_OBJECT_CLASS (gdk_wayland_subsurface_parent_class)->finalize (object);
 }
@@ -84,7 +85,7 @@ get_shm_wl_buffer (GdkWaylandSubsurface *self,
 
   width = gdk_texture_get_width (texture);
   height = gdk_texture_get_height (texture);
-  surface = gdk_wayland_display_create_shm_surface (display, width, height, &GDK_FRACTIONAL_SCALE_INIT_INT (1));
+  surface = gdk_wayland_display_create_shm_surface (display, width, height);
 
   downloader = gdk_texture_downloader_new (texture);
 
@@ -266,7 +267,7 @@ get_gl_texture_wl_buffer (GdkWaylandSubsurface *self,
                                gdk_texture_get_width (texture),
                                gdk_texture_get_height (texture),
                                &gl_buffer_listener,
-                               g_memdup (&gldata, sizeof (gldata)));
+                               g_memdup2 (&gldata, sizeof (gldata)));
 }
 
 static struct wl_buffer *
@@ -945,3 +946,27 @@ gdk_wayland_surface_create_subsurface (GdkSurface *surface)
   return GDK_SUBSURFACE (sub);
 }
 
+gboolean
+gdk_wayland_subsurface_inhibit_idle (GdkSubsurface *subsurface)
+{
+  GdkWaylandSubsurface *sub = GDK_WAYLAND_SUBSURFACE (subsurface);
+  GdkWaylandDisplay *display_wayland = GDK_WAYLAND_DISPLAY (gdk_surface_get_display (subsurface->parent));
+
+  if (!display_wayland->idle_inhibit_manager)
+    return FALSE;
+
+  if (!sub->idle_inhibitor)
+    sub->idle_inhibitor =
+      zwp_idle_inhibit_manager_v1_create_inhibitor (display_wayland->idle_inhibit_manager,
+                                                    sub->surface);
+
+  return TRUE;
+}
+
+void
+gdk_wayland_subsurface_uninhibit_idle (GdkSubsurface *subsurface)
+{
+  GdkWaylandSubsurface *sub = GDK_WAYLAND_SUBSURFACE (subsurface);
+
+  g_clear_pointer (&sub->idle_inhibitor, zwp_idle_inhibitor_v1_destroy);
+}
