@@ -216,10 +216,13 @@ struct _GtkInspectorRecorder
   gboolean highlight_sequences;
   gboolean record_events;
   gboolean stop_after_next_frame;
+  gboolean dark;
 
   GdkEventSequence *selected_sequence;
 
   GtkInspectorEventRecording *last_event_recording;
+
+  GSettings *settings;
 };
 
 typedef struct _GtkInspectorRecorderClass
@@ -236,6 +239,7 @@ enum
   PROP_HIGHLIGHT_SEQUENCES,
   PROP_SELECTED_SEQUENCE,
   PROP_RECORD_EVENTS,
+  PROP_DARK,
   LAST_PROP
 };
 
@@ -2110,25 +2114,6 @@ render_node_clip (GtkButton            *button,
   gdk_clipboard_set (clipboard, GSK_TYPE_RENDER_NODE, node);
 }
 
-static void
-toggle_dark_mode (GtkToggleButton *button,
-                  GParamSpec      *pspec,
-                  gpointer         data)
-{
-  GtkWidget *picture = data;
-
-  if (gtk_toggle_button_get_active (button))
-    {
-      gtk_widget_add_css_class (picture, "dark");
-      gtk_widget_remove_css_class (picture, "light");
-    }
-  else
-    {
-      gtk_widget_remove_css_class (picture, "dark");
-      gtk_widget_add_css_class (picture, "light");
-    }
-}
-
 static void
 setup_widget_for_recording (GtkListItemFactory *factory,
                             GtkListItem        *item,
@@ -2281,6 +2266,31 @@ bind_widget_for_recording (GtkListItemFactory *factory,
     }
 }
 
+static void
+recorder_set_dark (GtkInspectorRecorder *recorder,
+                   gboolean              dark)
+{
+  GtkWidget *picture = recorder->render_node_view;
+
+  if (recorder->dark == dark)
+    return;
+
+  recorder->dark = dark;
+
+  if (dark)
+    {
+      gtk_widget_add_css_class (picture, "dark");
+      gtk_widget_remove_css_class (picture, "light");
+    }
+  else
+    {
+      gtk_widget_remove_css_class (picture, "dark");
+      gtk_widget_add_css_class (picture, "light");
+    }
+
+  g_object_notify_by_pspec (G_OBJECT (recorder), props[PROP_DARK]);
+}
+
 static void
 gtk_inspector_recorder_get_property (GObject    *object,
                                      guint       param_id,
@@ -2311,6 +2321,10 @@ gtk_inspector_recorder_get_property (GObject    *object,
       g_value_set_pointer (value, recorder->selected_sequence);
       break;
 
+    case PROP_DARK:
+      g_value_set_boolean (value, recorder->dark);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
       break;
@@ -2347,6 +2361,10 @@ gtk_inspector_recorder_set_property (GObject      *object,
       recorder->selected_sequence = g_value_get_pointer (value);
       break;
 
+    case PROP_DARK:
+      recorder_set_dark (recorder, g_value_get_boolean (value));
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
       break;
@@ -2364,6 +2382,8 @@ gtk_inspector_recorder_dispose (GObject *object)
 
   gtk_widget_dispose_template (GTK_WIDGET (recorder), GTK_TYPE_INSPECTOR_RECORDER);
 
+  g_clear_object (&recorder->settings);
+
   G_OBJECT_CLASS (gtk_inspector_recorder_parent_class)->dispose (object);
 }
 
@@ -2382,12 +2402,14 @@ gtk_inspector_recorder_class_init (GtkInspectorRecorderClass *klass)
   props[PROP_DEBUG_NODES] = g_param_spec_boolean ("debug-nodes", NULL, NULL, FALSE, G_PARAM_READWRITE);
   props[PROP_HIGHLIGHT_SEQUENCES] = g_param_spec_boolean ("highlight-sequences", NULL, NULL, FALSE, G_PARAM_READWRITE);
   props[PROP_SELECTED_SEQUENCE] = g_param_spec_pointer ("selected-sequence", NULL, NULL, G_PARAM_READWRITE);
+  props[PROP_DARK] = g_param_spec_boolean ("dark", NULL, NULL, FALSE, G_PARAM_READWRITE);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
   gtk_widget_class_install_property_action (widget_class, "record.record-events", "record-events");
   gtk_widget_class_install_property_action (widget_class, "record.debug-nodes", "debug-nodes");
   gtk_widget_class_install_property_action (widget_class, "record.highlight-sequences", "highlight-sequences");
+  gtk_widget_class_install_property_action (widget_class, "record.toggle-dark", "dark");
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gtk/libgtk/inspector/recorder.ui");
 
@@ -2408,7 +2430,6 @@ gtk_inspector_recorder_class_init (GtkInspectorRecorderClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, render_node_save);
   gtk_widget_class_bind_template_callback (widget_class, render_node_clip);
   //gtk_widget_class_bind_template_callback (widget_class, node_property_activated);
-  gtk_widget_class_bind_template_callback (widget_class, toggle_dark_mode);
 
   gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
 }
@@ -2497,6 +2518,13 @@ gtk_inspector_recorder_init (GtkInspectorRecorder *recorder)
   gtk_column_view_column_set_factory (column, factory);
   g_object_unref (factory);
   g_object_unref (column);
+
+  recorder->settings = g_settings_new ("org.gtk.gtk4.Inspector.Recorder");
+
+  g_settings_bind (recorder->settings, "debug-nodes", recorder, "debug-nodes", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind (recorder->settings, "record-events", recorder, "record-events", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind (recorder->settings, "highlight-sequences", recorder, "highlight-sequences", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind (recorder->settings, "dark", recorder, "dark", G_SETTINGS_BIND_DEFAULT);
 }
 
 static void
